==> jersey-media-json-jackson-2.42-sources.jar: org/glassfish/jersey/jackson/LocalizationMessages.java <==

package org.glassfish.jersey.jackson;

import java.util.Locale;
import java.util.ResourceBundle;
import org.glassfish.jersey.internal.l10n.Localizable;
import org.glassfish.jersey.internal.l10n.LocalizableMessageFactory;
import org.glassfish.jersey.internal.l10n.LocalizableMessageFactory.ResourceBundleSupplier;
import org.glassfish.jersey.internal.l10n.Localizer;


/**
 * Defines string formatting method for each constant in the resource file
 * 
 */
public final class LocalizationMessages {

    private final static String BUNDLE_NAME = "org.glassfish.jersey.jackson.localization";
    private final static LocalizableMessageFactory MESSAGE_FACTORY = new LocalizableMessageFactory(BUNDLE_NAME, new LocalizationMessages.BundleSupplier());
    private final static Localizer LOCALIZER = new Localizer();

    public static Localizable localizableERROR_JACKSON_STREAMREADCONSTRAINTS(Object arg0) {
        return MESSAGE_FACTORY.getMessage("error.jackson.streamreadconstraints", arg0);
    }

    /**
     * Error setting StreamReadConstraints: {0}. Possibly not Jackson 2.15?
     * 
     */
    public static String ERROR_JACKSON_STREAMREADCONSTRAINTS(Object arg0) {
        return LOCALIZER.localize(localizableERROR_JACKSON_STREAMREADCONSTRAINTS(arg0));
    }

    private static class BundleSupplier
        implements ResourceBundleSupplier
    {


        public ResourceBundle getResourceBundle(Locale locale) {
            return ResourceBundle.getBundle(BUNDLE_NAME, locale);
        }

    }

}

==> jersey-media-json-jackson-2.46-sources.jar: org/glassfish/jersey/jackson/LocalizationMessages.java <==

package org.glassfish.jersey.jackson;

import java.util.Locale;
import java.util.ResourceBundle;
import org.glassfish.jersey.internal.l10n.Localizable;
import org.glassfish.jersey.internal.l10n.LocalizableMessageFactory;
import org.glassfish.jersey.internal.l10n.LocalizableMessageFactory.ResourceBundleSupplier;
import org.glassfish.jersey.internal.l10n.Localizer;


/**
 * Defines string formatting method for each constant in the resource file
 * 
 */
public final class LocalizationMessages {

    private final static String BUNDLE_NAME = "org.glassfish.jersey.jackson.localization";
    private final static LocalizableMessageFactory MESSAGE_FACTORY = new LocalizableMessageFactory(BUNDLE_NAME, new LocalizationMessages.BundleSupplier());
    private final static Localizer LOCALIZER = new Localizer();

    public static Localizable localizableERROR_JACKSON_STREAMREADCONSTRAINTS(Object arg0) {
        return MESSAGE_FACTORY.getMessage("error.jackson.streamreadconstraints", arg0);
    }

    /**
     * Error setting StreamReadConstraints: {0}. Possibly not Jackson 2.15?
     * 
     */
    public static String ERROR_JACKSON_STREAMREADCONSTRAINTS(Object arg0) {
        return LOCALIZER.localize(localizableERROR_JACKSON_STREAMREADCONSTRAINTS(arg0));
    }

    public static Localizable localizableERROR_MODULES_NOT_LOADED(Object arg0) {
        return MESSAGE_FACTORY.getMessage("error.modules.not.loaded", arg0);
    }

    /**
     * Jackson modules could not be loaded: {0}
     * 
     */
    public static String ERROR_MODULES_NOT_LOADED(Object arg0) {
        return LOCALIZER.localize(localizableERROR_MODULES_NOT_LOADED(arg0));
    }

    public static Localizable localizableERROR_JACKSON_STREAMREADCONSTRAINTS_218(Object arg0) {
        return MESSAGE_FACTORY.getMessage("error.jackson.streamreadconstraints218", arg0);
    }

    /**
     * Error setting StreamReadConstraints: {0}. Possibly not Jackson 2.18?
     * 
     */
    public static String ERROR_JACKSON_STREAMREADCONSTRAINTS_218(Object arg0) {
        return LOCALIZER.localize(localizableERROR_JACKSON_STREAMREADCONSTRAINTS_218(arg0));
    }

    private static class BundleSupplier
        implements ResourceBundleSupplier
    {


        public ResourceBundle getResourceBundle(Locale locale) {
            return ResourceBundle.getBundle(BUNDLE_NAME, locale);
        }

    }

}
